@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2009-2022 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2009 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -311,6 +311,13 @@ void TextEdit::keyPressEvent(QKeyEvent* event)
 		textCursor().insertBlock();
 		event->accept();
 		ensureCursorVisible();
+
+		// Reset from headings to normal
+		QTextCursor cursor = textCursor();
+		QTextBlockFormat block_format = cursor.blockFormat();
+		block_format.setHeadingLevel(0);
+		cursor.setBlockFormat(block_format);
+
 		return;
 	}
 
@@ -798,7 +805,7 @@ void Document::print(QPrinter* printer)
 
 	// Apply headings
 	for (QTextBlock block = document->begin(); block.isValid(); block = block.next()) {
-		const int heading = block.blockFormat().property(QTextFormat::UserProperty).toInt();
+		const int heading = block.blockFormat().headingLevel();
 		if (!heading) {
 			continue;
 		}
@@ -1139,6 +1146,7 @@ bool Document::eventFilter(QObject* watched, QEvent* event)
 	} else if (event->type() == QEvent::KeyPress && watched == m_text) {
 		m_daily_progress->increaseTime();
 		if (SmartQuotes::isEnabled() && SmartQuotes::insert(m_text, static_cast<QKeyEvent*>(event))) {
+			Sound::play(Qt::Key_Any);
 			return true;
 		}
 	} else if (event->type() == QEvent::Drop) {
@@ -1430,9 +1438,9 @@ void Document::calculateWordCount()
 
 	// Determine document stats by adding cached stats to current block stats
 	m_document_stats = m_cached_stats;
-	const QTextBlockUserData* data = m_text->document()->findBlockByNumber(m_cached_current_block).userData();
-	if (data) {
-		m_document_stats.append(static_cast<const BlockStats*>(data));
+	const QTextBlockUserData* stats = m_text->document()->findBlockByNumber(m_cached_current_block).userData();
+	if (stats) {
+		m_document_stats.append(static_cast<const BlockStats*>(stats));
 	}
 	m_document_stats.calculateWordCount(m_wordcount_type);
 	m_document_stats.calculatePageCount(m_page_type, m_page_amount);
@@ -1487,18 +1495,18 @@ QString Document::getSaveFileName(const QString& title)
 		static const QRegularExpression regex("\\*(\\.\\w+)");
 		QRegularExpressionMatchIterator i = regex.globalMatch(selected);
 		bool append_extension = i.hasNext();
-		QStringList types;
+		QStringList extensions;
 		while (i.hasNext()) {
-			const QString type = i.next().captured(1);
-			types << type;
+			const QString extension = i.next().captured(1);
+			extensions << extension;
 
-			if (filename.endsWith(type)) {
+			if (filename.endsWith(extension)) {
 				append_extension = false;
 				break;
 			}
 		}
 		if (append_extension) {
-			filename.append(types.constFirst());
+			filename.append(extensions.constFirst());
 		}
 
 		// Handle rich text in plain text file
